package com.company.jmixtest.screen.main

import io.jmix.core.session.SessionData
import io.jmix.core.usersubstitution.CurrentUserSubstitution
import io.jmix.core.usersubstitution.UserSubstitutionManager
import io.jmix.ui.Notifications
import io.jmix.ui.ScreenTools
import io.jmix.ui.component.AppWorkArea
import io.jmix.ui.component.Button
import io.jmix.ui.component.Window.HasWorkArea
import io.jmix.ui.component.mainwindow.Drawer
import io.jmix.ui.icon.JmixIcon
import io.jmix.ui.navigation.Route
import io.jmix.ui.screen.*
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.context.event.EventListener

@UiController("jt_MainScreen")
@UiDescriptor("main-screen.xml")
@Route(path = "main", root = true)
open class MainScreen : Screen(), HasWorkArea {

    @Autowired
    private lateinit var screenTools: ScreenTools

    @Autowired
    private lateinit var workArea: AppWorkArea

    @Autowired
    private lateinit var drawer: Drawer

    @Autowired
    private lateinit var collapseDrawerButton: Button

    @Autowired
    private lateinit var notifications: Notifications

    @Autowired
    private lateinit var sessionData: SessionData

    @Autowired
    private lateinit var currentUserSubstitution: CurrentUserSubstitution

    @Autowired
    private lateinit var userSubstitutionManager: UserSubstitutionManager

    override fun getWorkArea(): AppWorkArea = workArea

    @Subscribe("collapseDrawerButton")
    private fun onCollapseDrawerButtonClick(event: Button.ClickEvent) {
        drawer.run {
            toggle()
            if (isCollapsed) {
                collapseDrawerButton.setIconFromSet(JmixIcon.CHEVRON_RIGHT)
            } else {
                collapseDrawerButton.setIconFromSet(JmixIcon.CHEVRON_LEFT)
            }
        }
    }

    @Subscribe
    fun onAfterShow(event: AfterShowEvent?) {
        screenTools.run {
            openDefaultScreen(
                UiControllerUtils.getScreenContext(this@MainScreen).screens
            )
            handleRedirect()
        }
    }

}